@@ -176,6 +176,9 @@ class ResourceHandle(object):
     def __eq__(self, other):
         return (self.key == other.key) and (self.variables == other.variables)
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def __hash__(self):
         return hash(self._hashable_repr())
 
